==> ui-0.0.0-dev1267-sources.jar: skikoMain/androidx/compose/ui/input/pointer/InternalPointerEvent.skiko.kt <==
/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.ui.input.pointer

import androidx.compose.ui.ExperimentalComposeUiApi

@OptIn(ExperimentalComposeUiApi::class)
internal actual class InternalPointerEvent constructor(
    val type: PointerEventType,
    actual val changes: Map<PointerId, PointerInputChange>,
    val buttons: PointerButtons,
    val keyboardModifiers: PointerKeyboardModifiers,
    val nativeEvent: Any?,
    val button: PointerButton?
) {
    actual constructor(
        changes: Map<PointerId, PointerInputChange>,
        pointerInputEvent: PointerInputEvent
    ) : this(
        pointerInputEvent.eventType,
        changes,
        pointerInputEvent.buttons,
        pointerInputEvent.keyboardModifiers,
        pointerInputEvent.nativeEvent,
        pointerInputEvent.button
    )

    actual var suppressMovementConsumption: Boolean = false

    actual fun issuesEnterExitEvent(pointerId: PointerId): Boolean =
        changes[pointerId]?.type == PointerType.Mouse
}

==> ui-1.6.10-dev1575-sources.jar: skikoMain/androidx/compose/ui/input/pointer/InternalPointerEvent.skiko.kt <==
/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.ui.input.pointer

import androidx.collection.LongSparseArray

internal actual class InternalPointerEvent(
    val type: PointerEventType,
    actual val changes: LongSparseArray<PointerInputChange>,
    val buttons: PointerButtons,
    val keyboardModifiers: PointerKeyboardModifiers,
    val nativeEvent: Any?,
    val button: PointerButton?
) {
    actual constructor(
        changes: LongSparseArray<PointerInputChange>,
        pointerInputEvent: PointerInputEvent
    ) : this(
        pointerInputEvent.eventType,
        changes,
        pointerInputEvent.buttons,
        pointerInputEvent.keyboardModifiers,
        pointerInputEvent.nativeEvent,
        pointerInputEvent.button
    )

    actual var suppressMovementConsumption: Boolean = false

    actual fun issuesEnterExitEvent(pointerId: PointerId): Boolean =
        changes[pointerId.value]?.type == PointerType.Mouse
}
